==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import javax.xml.namespace.QName;
import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.positionequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private static final QName _NonDependentParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/PositionEquipment_001", "NonDependentParents");
    private static final QName _NoParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/PositionEquipment_001", "NoParents");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.positionequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link PositionEquipment }
     * 
     * @return
     *     the new instance of {@link PositionEquipment }
     */
    public PositionEquipment createPositionEquipment() {
        return new PositionEquipment();
    }

    /**
     * Create an instance of {@link ChildPosition }
     * 
     * @return
     *     the new instance of {@link ChildPosition }
     */
    public ChildPosition createChildPosition() {
        return new ChildPosition();
    }

    /**
     * Create an instance of {@link PositionEquipment.DORMANT }
     * 
     * @return
     *     the new instance of {@link PositionEquipment.DORMANT }
     */
    public PositionEquipment.DORMANT createPositionEquipmentDORMANT() {
        return new PositionEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     * @return
     *     the new instance of {@link ManufacturerInfo }
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     * @return
     *     the new instance of {@link Variables }
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     * @return
     *     the new instance of {@link CallCenterDetails }
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     * @return
     *     the new instance of {@link UserDefinedFields }
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     * @return
     *     the new instance of {@link FacilityConditionIndex }
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link PositionEquipment.PERFORMANCEDETAILS }
     * 
     * @return
     *     the new instance of {@link PositionEquipment.PERFORMANCEDETAILS }
     */
    public PositionEquipment.PERFORMANCEDETAILS createPositionEquipmentPERFORMANCEDETAILS() {
        return new PositionEquipment.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link PositionChildHierarchy }
     * 
     * @return
     *     the new instance of {@link PositionChildHierarchy }
     */
    public PositionChildHierarchy createPositionChildHierarchy() {
        return new PositionChildHierarchy();
    }

    /**
     * Create an instance of {@link PositionParentHierarchy }
     * 
     * @return
     *     the new instance of {@link PositionParentHierarchy }
     */
    public PositionParentHierarchy createPositionParentHierarchy() {
        return new PositionParentHierarchy();
    }

    /**
     * Create an instance of {@link PositionDependency }
     * 
     * @return
     *     the new instance of {@link PositionDependency }
     */
    public PositionDependency createPositionDependency() {
        return new PositionDependency();
    }

    /**
     * Create an instance of {@link SystemDependency }
     * 
     * @return
     *     the new instance of {@link SystemDependency }
     */
    public SystemDependency createSystemDependency() {
        return new SystemDependency();
    }

    /**
     * Create an instance of {@link PrimarySystemDependency }
     * 
     * @return
     *     the new instance of {@link PrimarySystemDependency }
     */
    public PrimarySystemDependency createPrimarySystemDependency() {
        return new PrimarySystemDependency();
    }

    /**
     * Create an instance of {@link LocationDependency }
     * 
     * @return
     *     the new instance of {@link LocationDependency }
     */
    public LocationDependency createLocationDependency() {
        return new LocationDependency();
    }

    /**
     * Create an instance of {@link NonDependentParents_Type }
     * 
     * @return
     *     the new instance of {@link NonDependentParents_Type }
     */
    public NonDependentParents_Type createNonDependentParents_Type() {
        return new NonDependentParents_Type();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link NonDependentParents_Type }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link NonDependentParents_Type }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", name = "NonDependentParents")
    public JAXBElement<NonDependentParents_Type> createNonDependentParents(NonDependentParents_Type value) {
        return new JAXBElement<>(_NonDependentParents_QNAME, NonDependentParents_Type.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link String }{@code >}
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", name = "NoParents")
    public JAXBElement<String> createNoParents(String value) {
        return new JAXBElement<>(_NoParents_QNAME, String.class, null, value);
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_entities/positionequipment_001/ObjectFactory.java <==

package net.datastream.schemas.mp_entities.positionequipment_001;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_entities.positionequipment_001 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _NoParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/PositionEquipment_001", "NoParents");
    private final static QName _NonDependentParents_QNAME = new QName("http://schemas.datastream.net/MP_entities/PositionEquipment_001", "NonDependentParents");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_entities.positionequipment_001
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link PositionEquipment }
     * 
     */
    public PositionEquipment createPositionEquipment() {
        return new PositionEquipment();
    }

    /**
     * Create an instance of {@link ChildPosition }
     * 
     */
    public ChildPosition createChildPosition() {
        return new ChildPosition();
    }

    /**
     * Create an instance of {@link NonDependentParents_Type }
     * 
     */
    public NonDependentParents_Type createNonDependentParents_Type() {
        return new NonDependentParents_Type();
    }

    /**
     * Create an instance of {@link ManufacturerInfo }
     * 
     */
    public ManufacturerInfo createManufacturerInfo() {
        return new ManufacturerInfo();
    }

    /**
     * Create an instance of {@link PrimarySystemDependency }
     * 
     */
    public PrimarySystemDependency createPrimarySystemDependency() {
        return new PrimarySystemDependency();
    }

    /**
     * Create an instance of {@link LocationDependency }
     * 
     */
    public LocationDependency createLocationDependency() {
        return new LocationDependency();
    }

    /**
     * Create an instance of {@link UserDefinedFields }
     * 
     */
    public UserDefinedFields createUserDefinedFields() {
        return new UserDefinedFields();
    }

    /**
     * Create an instance of {@link SystemDependency }
     * 
     */
    public SystemDependency createSystemDependency() {
        return new SystemDependency();
    }

    /**
     * Create an instance of {@link PositionParentHierarchy }
     * 
     */
    public PositionParentHierarchy createPositionParentHierarchy() {
        return new PositionParentHierarchy();
    }

    /**
     * Create an instance of {@link PositionDependency }
     * 
     */
    public PositionDependency createPositionDependency() {
        return new PositionDependency();
    }

    /**
     * Create an instance of {@link PositionEquipment.DORMANT }
     * 
     */
    public PositionEquipment.DORMANT createPositionEquipmentDORMANT() {
        return new PositionEquipment.DORMANT();
    }

    /**
     * Create an instance of {@link Variables }
     * 
     */
    public Variables createVariables() {
        return new Variables();
    }

    /**
     * Create an instance of {@link CallCenterDetails }
     * 
     */
    public CallCenterDetails createCallCenterDetails() {
        return new CallCenterDetails();
    }

    /**
     * Create an instance of {@link FacilityConditionIndex }
     * 
     */
    public FacilityConditionIndex createFacilityConditionIndex() {
        return new FacilityConditionIndex();
    }

    /**
     * Create an instance of {@link PositionEquipment.PERFORMANCEDETAILS }
     * 
     */
    public PositionEquipment.PERFORMANCEDETAILS createPositionEquipmentPERFORMANCEDETAILS() {
        return new PositionEquipment.PERFORMANCEDETAILS();
    }

    /**
     * Create an instance of {@link PositionChildHierarchy }
     * 
     */
    public PositionChildHierarchy createPositionChildHierarchy() {
        return new PositionChildHierarchy();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link String }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", name = "NoParents")
    public JAXBElement<String> createNoParents(String value) {
        return new JAXBElement<String>(_NoParents_QNAME, String.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link NonDependentParents_Type }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://schemas.datastream.net/MP_entities/PositionEquipment_001", name = "NonDependentParents")
    public JAXBElement<NonDependentParents_Type> createNonDependentParents(NonDependentParents_Type value) {
        return new JAXBElement<NonDependentParents_Type>(_NonDependentParents_QNAME, NonDependentParents_Type.class, null, value);
    }

}
